@@ -432,7 +432,10 @@ def get_colors(cells, min_wins):
             min_wins = True
 
     # If we land here, both min_value and max_value are not None.
-    diff = float(max_value - min_value)
+    try:
+        diff = float(max_value - min_value)
+    except OverflowError:
+        return result
 
     for col, val in cells.items():
         if val is not None:
@@ -492,17 +495,9 @@ def get_unexplained_errors_message(run):
 
 def get_slurm_err_content(src_dir):
     grid_steps_dir = src_dir.rstrip("/") + "-grid-steps"
-    if os.path.exists(grid_steps_dir):
-        slurm_err_filename = os.path.join(grid_steps_dir, "slurm.err")
-        if os.path.exists(slurm_err_filename):
-            try:
-                with open(slurm_err_filename) as f:
-                    return f.read()
-            except OSError:
-                logging.error("Failed to read slurm.err file.")
-        else:
-            logging.error("File slurm.err is missing.")
-    return ""
+    slurm_err_filename = os.path.join(grid_steps_dir, "slurm.err")
+    with open(slurm_err_filename) as f:
+        return f.read()
 
 
 def filter_slurm_err_content(content):
@@ -528,7 +523,7 @@ class RawAndDefaultsHelpFormatter(argparse.HelpFormatter):
         argparse.HelpFormatter.__init__(self, prog, width=width, **kwargs)
 
     def _fill_text(self, text, width, indent):
-        return "\n".join([indent + line for line in text.splitlines()])
+        return "\n".join(indent + line for line in text.splitlines())
 
     def _get_help_string(self, action):
         help = action.help
